@@ -1,27 +1,13 @@
+/*
+ * SPDX-License-Identifier: MIT
+ *
+ * Copyright (C) 2010-2019 EfficiOS Inc. and Linux Foundation
+ */
+
 #ifndef BABELTRACE2_GRAPH_COMPONENT_CLASS_H
 #define BABELTRACE2_GRAPH_COMPONENT_CLASS_H
 
-/*
- * Copyright (c) 2010-2019 EfficiOS Inc. and Linux Foundation
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
+/* IWYU pragma: private, include <babeltrace2/babeltrace.h> */
 
 #ifndef __BT_IN_BABELTRACE_H
 # error "Please include <babeltrace2/babeltrace.h> instead."
@@ -45,9 +31,9 @@ A <strong><em>component class</em></strong> is the class of a \bt_comp:
 @image html component.png
 
 @attention
-    This module (component class API) offers basic, read-only functions
-    to get component class properties. To \em create a component class,
-    see \ref api-comp-cls-dev or \ref api-plugin-dev.
+    This API (component class API) offers basic,
+    read-only functions to get component class properties. To \em create
+    a component class, see \ref api-comp-cls-dev or \ref api-plugin-dev.
 
 You can instantiate a given component class many times, with different
 initialization parameters, to create many components with the
@@ -55,12 +41,12 @@ initialization parameters, to create many components with the
 
 There are two ways to obtain a component class:
 
-- Create one programatically: see \ref api-comp-cls-dev.
+- Create one programmatically: see \ref api-comp-cls-dev.
 
 - Borrow one from a \bt_plugin.
 
   Note that, as of \bt_name_version_min_maj, you cannot access a
-  component class's plugin, if any.
+  the plugin of component class, if any.
 
 A component class is a \ref api-fund-shared-object "shared object": get
 a new reference with bt_component_class_get_ref() and put an existing
@@ -76,7 +62,7 @@ There are three types of component classes:
     A source component class instance (a \bt_src_comp) \bt_msg_iter
     emits fresh \bt_p_msg.
 
-    A source component class's specific type is
+    The specific type of a source component class is
     #bt_component_class_source and its type enumerator is
     #BT_COMPONENT_CLASS_TYPE_SOURCE.
 
@@ -95,7 +81,7 @@ There are three types of component classes:
     emits fresh and transformed messages. It can also discard
     existing messages.
 
-    A filter component class's specific type is
+    The specific type of a filter component class is
     #bt_component_class_filter and its type enumerator is
     #BT_COMPONENT_CLASS_TYPE_FILTER.
 
@@ -113,8 +99,9 @@ There are three types of component classes:
     A sink component class instance (a \bt_sink_comp) consumes messages
     from a source or filter message iterator.
 
-    A filter component class's specific type is #bt_component_class_sink
-    and its type enumerator is #BT_COMPONENT_CLASS_TYPE_SINK.
+    The specific type of a filter component class is
+    #bt_component_class_sink and its type enumerator is
+    #BT_COMPONENT_CLASS_TYPE_SINK.
 
     \ref api-fund-c-typing "Upcast" the #bt_component_class_sink type to
     the #bt_component_class type with
@@ -126,7 +113,7 @@ There are three types of component classes:
   </dd>
 </dl>
 
-Get a component's class type enumerator with
+Get the type enumerator of the class of a component with
 bt_component_class_get_type(). You can also use the
 bt_component_class_is_source(), bt_component_class_is_filter(), and
 bt_component_class_is_sink() helper functions.
@@ -146,7 +133,8 @@ A component class has the following common properties:
     Within a \bt_plugin, for a given component class type, each
     component class has a unique name.
 
-    Get a component class's name with bt_component_class_get_name().
+    Get the name of a component class with
+    bt_component_class_get_name().
   </dd>
 
   <dt>
@@ -156,7 +144,7 @@ A component class has the following common properties:
   <dd>
     Textual description of the component class.
 
-    Get a component class's description with
+    Get the description of a component class with
     bt_component_class_get_description().
   </dd>
 
@@ -167,7 +155,7 @@ A component class has the following common properties:
   <dd>
     Help text of the component class.
 
-    Get a component class's help text with
+    Get the help text of a component class with
     bt_component_class_get_help().
   </dd>
 </dl>
@@ -252,7 +240,7 @@ typedef enum bt_component_class_type {
     Returns whether or not a component class is a \bt_sink_comp_cls.
 */
 extern bt_component_class_type bt_component_class_get_type(
-		const bt_component_class *component_class);
+		const bt_component_class *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -272,7 +260,7 @@ extern bt_component_class_type bt_component_class_get_type(
 */
 static inline
 bt_bool bt_component_class_is_source(
-		const bt_component_class *component_class)
+		const bt_component_class *component_class) __BT_NOEXCEPT
 {
 	return bt_component_class_get_type(component_class) ==
 		BT_COMPONENT_CLASS_TYPE_SOURCE;
@@ -296,7 +284,7 @@ bt_bool bt_component_class_is_source(
 */
 static inline
 bt_bool bt_component_class_is_filter(
-		const bt_component_class *component_class)
+		const bt_component_class *component_class) __BT_NOEXCEPT
 {
 	return bt_component_class_get_type(component_class) ==
 		BT_COMPONENT_CLASS_TYPE_FILTER;
@@ -320,7 +308,7 @@ bt_bool bt_component_class_is_filter(
 */
 static inline
 bt_bool bt_component_class_is_sink(
-		const bt_component_class *component_class)
+		const bt_component_class *component_class) __BT_NOEXCEPT
 {
 	return bt_component_class_get_type(component_class) ==
 		BT_COMPONENT_CLASS_TYPE_SINK;
@@ -353,7 +341,7 @@ See the \ref api-comp-cls-prop-name "name" property.
 @bt_pre_not_null{component_class}
 */
 extern const char *bt_component_class_get_name(
-		const bt_component_class *component_class);
+		const bt_component_class *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -376,7 +364,7 @@ See the \ref api-comp-cls-prop-descr "description" property.
 @bt_pre_not_null{component_class}
 */
 extern const char *bt_component_class_get_description(
-		const bt_component_class *component_class);
+		const bt_component_class *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -398,7 +386,7 @@ See the \ref api-comp-cls-prop-help "help text" property.
 @bt_pre_not_null{component_class}
 */
 extern const char *bt_component_class_get_help(
-		const bt_component_class *component_class);
+		const bt_component_class *component_class) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -423,7 +411,7 @@ extern const char *bt_component_class_get_help(
     Decrements the reference count of a component class.
 */
 extern void bt_component_class_get_ref(
-		const bt_component_class *component_class);
+		const bt_component_class *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -441,7 +429,7 @@ extern void bt_component_class_get_ref(
     Increments the reference count of a component class.
 */
 extern void bt_component_class_put_ref(
-		const bt_component_class *component_class);
+		const bt_component_class *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -523,7 +511,7 @@ expression
 static inline
 const bt_component_class *
 bt_component_class_source_as_component_class_const(
-		const bt_component_class_source *component_class)
+		const bt_component_class_source *component_class) __BT_NOEXCEPT
 {
 	return __BT_UPCAST_CONST(bt_component_class, component_class);
 }
@@ -551,7 +539,7 @@ bt_component_class_source_as_component_class_const(
     Decrements the reference count of a source component class.
 */
 extern void bt_component_class_source_get_ref(
-		const bt_component_class_source *component_class);
+		const bt_component_class_source *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -569,7 +557,7 @@ extern void bt_component_class_source_get_ref(
     Increments the reference count of a source component class.
 */
 extern void bt_component_class_source_put_ref(
-		const bt_component_class_source *component_class);
+		const bt_component_class_source *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -650,7 +638,7 @@ existing \bt_p{_dst} reference.
 static inline
 const bt_component_class *
 bt_component_class_filter_as_component_class_const(
-		const bt_component_class_filter *component_class)
+		const bt_component_class_filter *component_class) __BT_NOEXCEPT
 {
 	return __BT_UPCAST_CONST(bt_component_class, component_class);
 }
@@ -678,7 +666,7 @@ bt_component_class_filter_as_component_class_const(
     Decrements the reference count of a filter component class.
 */
 extern void bt_component_class_filter_get_ref(
-		const bt_component_class_filter *component_class);
+		const bt_component_class_filter *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -696,7 +684,7 @@ extern void bt_component_class_filter_get_ref(
     Increments the reference count of a filter component class.
 */
 extern void bt_component_class_filter_put_ref(
-		const bt_component_class_filter *component_class);
+		const bt_component_class_filter *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -777,7 +765,7 @@ existing \bt_p{_dst} reference.
 static inline
 const bt_component_class *
 bt_component_class_sink_as_component_class_const(
-		const bt_component_class_sink *component_class)
+		const bt_component_class_sink *component_class) __BT_NOEXCEPT
 {
 	return __BT_UPCAST_CONST(bt_component_class, component_class);
 }
@@ -805,7 +793,7 @@ bt_component_class_sink_as_component_class_const(
     Decrements the reference count of a sink component class.
 */
 extern void bt_component_class_sink_get_ref(
-		const bt_component_class_sink *component_class);
+		const bt_component_class_sink *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -823,7 +811,7 @@ extern void bt_component_class_sink_get_ref(
     Increments the reference count of a sink component class.
 */
 extern void bt_component_class_sink_put_ref(
-		const bt_component_class_sink *component_class);
+		const bt_component_class_sink *component_class) __BT_NOEXCEPT;
 
 /*!
 @brief
