@@ -1,27 +1,13 @@
+/*
+ * SPDX-License-Identifier: MIT
+ *
+ * Copyright (C) 2010-2019 EfficiOS Inc. and Linux Foundation
+ */
+
 #ifndef BABELTRACE2_PLUGIN_PLUGIN_DEV_H
 #define BABELTRACE2_PLUGIN_PLUGIN_DEV_H
 
-/*
- * Copyright (c) 2010-2019 EfficiOS Inc. and Linux Foundation
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
+/* IWYU pragma: private, include <babeltrace2/babeltrace.h> */
 
 #ifndef __BT_IN_BABELTRACE_H
 # error "Please include <babeltrace2/babeltrace.h> instead."
@@ -44,6 +30,15 @@
 #define _BT_HIDDEN __attribute__((visibility("hidden")))
 #endif
 
+/*
+ * _BT_EXPORT: set the visibility for exported functions.
+ */
+#if defined(_WIN32) || defined(__CYGWIN__)
+#define _BT_EXPORT
+#else
+#define _BT_EXPORT __attribute__((visibility("default")))
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -54,13 +49,14 @@ extern "C" {
 @brief
     Shared object plugin development.
 
-This module offers macros to create a \bt_name shared object plugin.
+This API offers macros to create a \bt_name shared
+object plugin.
 
-Behind the scenes, the <code>BT_PLUGIN_*()</code> macros of this module
-create and fill global tables which are located in sections of the
-shared object with specific names. The \ref api-plugin functions can
-load the resulting shared object file and create corresponding
-\bt_plugin objects.
+Behind the scenes, the <code>BT_PLUGIN_*()</code> macros of this
+API create and fill global tables which are located in
+sections of the shared object with specific names. The \ref api-plugin
+functions can load the resulting shared object file and create
+corresponding \bt_plugin objects.
 
 See \ref guide-comp-link-plugin-so.
 
@@ -78,14 +74,15 @@ The structure of a \bt_name plugin definition C file is as such:
   </li>
 
   <li>
-    Define a \bt_name plugin with BT_PLUGIN() if the plugin's name is a
-    valid C identifier, or with BT_PLUGIN_WITH_ID() otherwise.
+    Define a \bt_name plugin with BT_PLUGIN() if the name of the plugin
+    is a valid C identifier, or with BT_PLUGIN_WITH_ID() otherwise.
 
     See \ref api-plugin-dev-custom-plugin-id "Custom plugin ID" to
     learn more about plugin IDs.
 
     @note
-        When you use BT_PLUGIN(), the plugin's ID is <code>auto</code>.
+        When you use BT_PLUGIN(), the ID of the plugin is
+        <code>auto</code>.
   </li>
 
   <li>
@@ -107,12 +104,12 @@ The structure of a \bt_name plugin definition C file is as such:
     - BT_PLUGIN_INITIALIZE_FUNC()
     - BT_PLUGIN_FINALIZE_FUNC()
 
-    A plugin's initialization function is executed when the shared
+    The initialization function of a plugin is executed when the shared
     object is loaded (see \ref api-plugin).
 
-    A plugin's finalization function is executed when the \bt_plugin
-    object is destroyed, if the initialization function (if any)
-    succeeded.
+    The finalization function of a plugin is executed when the
+    \bt_plugin object is destroyed, if the initialization function (if
+    any) succeeded.
   </li>
 
   <li>
@@ -125,9 +122,9 @@ The structure of a \bt_name plugin definition C file is as such:
   </li>
 
   <li>
-    \bt_dt_opt Depending on the type of the component class of step 5,
-    use any of the following macros (or their <code>*_WITH_ID()</code>
-    counterpart)
+    \bt_dt_opt Depending on the type of the component class of
+    step&nbsp;5, use any of the following macros (or their
+    <code>*_WITH_ID()</code> counterpart)
     \em once to set its properties:
 
     <dl>
@@ -152,9 +149,9 @@ The structure of a \bt_name plugin definition C file is as such:
   </li>
 
   <li>
-    \bt_dt_opt Depending on the type of the component class of step 5,
-    use any of the following macros (or their <code>*_WITH_ID()</code>
-    counterpart) to set its optional methods:
+    \bt_dt_opt Depending on the type of the component class of
+    step&nbsp;5, use any of the following macros (or their
+    <code>*_WITH_ID()</code> counterpart) to set its optional methods:
 
     <dl>
       <dt>Source component class</dt>
@@ -193,32 +190,32 @@ The structure of a \bt_name plugin definition C file is as such:
   </li>
 </ol>
 
-You can repeat steps 5 to 7 to add more than one component class to a
-given plugin.
+You can repeat steps&nbsp;5 to&nbsp;7 to add more than one component
+class to a given plugin.
 
 See \ref example-simple-plugin-def-file for a concrete example of how
-to use the macros of this module.
+to use the macros of this API.
 
 <h1>\anchor api-plugin-dev-custom-plugin-id Custom plugin ID</h1>
 
 The BT_PLUGIN() macro defines a plugin with a specific name and the
 ID <code>auto</code>.
 
-All the <code>BT_PLUGIN_*()</code> macros which do not end with
+All the <code>BT_PLUGIN_*()</code> macros which don't end with
 <code>_WITH_ID</code> refer to the <code>auto</code> plugin.
 
 There are two situations which demand that you use a custom plugin ID:
 
 - You want more than one plugin contained in your shared object file.
 
-  Although the \bt_name project does not recommend this, it is possible.
+  Although the \bt_name project doesn't recommend this, it's possible.
   This is why bt_plugin_find_all_from_file() returns a \bt_plugin_set
   instead of a single \bt_plugin.
 
   In this case, each plugin of the shared object needs its own, unique
   ID.
 
-- You want to give the plugin a name which is not a valid C identifier.
+- You want to give the plugin a name which isn't a valid C identifier.
 
   The BT_PLUGIN() macro accepts a C identifier as the plugin name, while
   the BT_PLUGIN_WITH_ID() accepts a C identifier for the ID and a C
@@ -242,7 +239,7 @@ BT_PLUGIN_AUTHOR_WITH_ID(my_plugin_id, "Patrick Bouchard");
     @parblock
     You can still use the <code>auto</code> ID with BT_PLUGIN_WITH_ID()
     to use the simpler macros afterwards while still giving the plugin a
-    name which is not a valid C identifier, for example:
+    name which isn't a valid C identifier, for example:
 
     @code
     BT_PLUGIN_WITH_ID(auto, "my-plugin-name");
@@ -258,8 +255,8 @@ BT_PLUGIN_SINK_COMPONENT_CLASS() add a component class with a specific
 name to the plugin having the ID <code>auto</code>.
 
 The name you pass to those macros must be a valid C identifier and it
-also serves as the component class's ID within the <code>auto</code>
-plugin.
+also serves as the ID of the component class within the
+<code>auto</code> plugin.
 
 There are two situations which demand that you use a custom component
 class ID:
@@ -267,7 +264,7 @@ class ID:
 - You want to add the component class to a specific plugin (other than
   <code>auto</code>, if you have more than one).
 
-- You want to give the component class a name which is not a valid C
+- You want to give the component class a name which isn't a valid C
   identifier.
 
   The <code>BT_PLUGIN_*_COMPONENT_CLASS_WITH_ID()</code> macros accept a
@@ -332,8 +329,8 @@ BT_PLUGIN_SOURCE_COMPONENT_CLASS_FINALIZE_METHOD_WITH_ID(my_plugin_id,
 @brief
     Defines a plugin module.
 
-In a plugin define C file, you must use this macro before you use any
-other <code>BT_PLUGIN*()</code> macro.
+In a plugin definition C file, you must use this macro before you use
+any other <code>BT_PLUGIN*()</code> macro.
 */
 #define BT_PLUGIN_MODULE() \
 	static struct __bt_plugin_descriptor const * const __bt_plugin_descriptor_dummy __BT_PLUGIN_DESCRIPTOR_ATTRS = NULL; \
@@ -352,35 +349,35 @@ other <code>BT_PLUGIN*()</code> macro.
 	_BT_HIDDEN extern struct __bt_plugin_component_class_descriptor_attribute const *__BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_ATTRIBUTES_BEGIN_SYMBOL __BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_ATTRIBUTES_BEGIN_EXTRA; \
 	_BT_HIDDEN extern struct __bt_plugin_component_class_descriptor_attribute const *__BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_ATTRIBUTES_END_SYMBOL __BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_ATTRIBUTES_END_EXTRA; \
 	\
-	struct __bt_plugin_descriptor const * const *__bt_get_begin_section_plugin_descriptors(void) \
+	_BT_EXPORT struct __bt_plugin_descriptor const * const *__bt_get_begin_section_plugin_descriptors(void) \
 	{ \
 		return &__BT_PLUGIN_DESCRIPTOR_BEGIN_SYMBOL; \
 	} \
-	struct __bt_plugin_descriptor const * const *__bt_get_end_section_plugin_descriptors(void) \
+	_BT_EXPORT struct __bt_plugin_descriptor const * const *__bt_get_end_section_plugin_descriptors(void) \
 	{ \
 		return &__BT_PLUGIN_DESCRIPTOR_END_SYMBOL; \
 	} \
-	struct __bt_plugin_descriptor_attribute const * const *__bt_get_begin_section_plugin_descriptor_attributes(void) \
+	_BT_EXPORT struct __bt_plugin_descriptor_attribute const * const *__bt_get_begin_section_plugin_descriptor_attributes(void) \
 	{ \
 		return &__BT_PLUGIN_DESCRIPTOR_ATTRIBUTES_BEGIN_SYMBOL; \
 	} \
-	struct __bt_plugin_descriptor_attribute const * const *__bt_get_end_section_plugin_descriptor_attributes(void) \
+	_BT_EXPORT struct __bt_plugin_descriptor_attribute const * const *__bt_get_end_section_plugin_descriptor_attributes(void) \
 	{ \
 		return &__BT_PLUGIN_DESCRIPTOR_ATTRIBUTES_END_SYMBOL; \
 	} \
-	struct __bt_plugin_component_class_descriptor const * const *__bt_get_begin_section_component_class_descriptors(void) \
+	_BT_EXPORT struct __bt_plugin_component_class_descriptor const * const *__bt_get_begin_section_component_class_descriptors(void) \
 	{ \
 		return &__BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_BEGIN_SYMBOL; \
 	} \
-	struct __bt_plugin_component_class_descriptor const * const *__bt_get_end_section_component_class_descriptors(void) \
+	_BT_EXPORT struct __bt_plugin_component_class_descriptor const * const *__bt_get_end_section_component_class_descriptors(void) \
 	{ \
 		return &__BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_END_SYMBOL; \
 	} \
-	struct __bt_plugin_component_class_descriptor_attribute const * const *__bt_get_begin_section_component_class_descriptor_attributes(void) \
+	_BT_EXPORT struct __bt_plugin_component_class_descriptor_attribute const * const *__bt_get_begin_section_component_class_descriptor_attributes(void) \
 	{ \
 		return &__BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_ATTRIBUTES_BEGIN_SYMBOL; \
 	} \
-	struct __bt_plugin_component_class_descriptor_attribute const * const *__bt_get_end_section_component_class_descriptor_attributes(void) \
+	_BT_EXPORT struct __bt_plugin_component_class_descriptor_attribute const * const *__bt_get_end_section_component_class_descriptor_attributes(void) \
 	{ \
 		return &__BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_ATTRIBUTES_END_SYMBOL; \
 	}
@@ -400,14 +397,14 @@ other <code>BT_PLUGIN*()</code> macro.
     @parblock
     C identifier.
 
-    Plugin's ID, unique amongst all the plugin IDs of the same shared
-    object.
+    ID of the plugin, unique amongst all the plugin IDs of the same
+    shared object.
     @endparblock
 @param[in] _name
     @parblock
     <code>const char *</code>
 
-    Plugin's name.
+    Name of the plugin.
     @endparblock
 
 @bt_pre_not_null{_name}
@@ -449,7 +446,7 @@ See the \ref api-comp-cls-prop-descr "description" property.
     @parblock
     <code>const char *</code>
 
-    Plugin's description.
+    Description of the plugin.
     @endparblock
 
 @bt_pre_not_null{_description}
@@ -464,7 +461,6 @@ See the \ref api-comp-cls-prop-descr "description" property.
 */
 #define BT_PLUGIN_DESCRIPTION(_description) 	BT_PLUGIN_DESCRIPTION_WITH_ID(auto, _description)
 
-
 /*!
 @brief
     Sets the name(s) of the author(s) of the plugin having the ID
@@ -482,7 +478,7 @@ See the \ref api-plugin-prop-author "author name(s)" property.
     @parblock
     <code>const char *</code>
 
-    Plugin's author(s).
+    Author(s) of the plugin.
     @endparblock
 
 @bt_pre_not_null{_author}
@@ -514,7 +510,7 @@ See the \ref api-plugin-prop-license "license" property.
     @parblock
     <code>const char *</code>
 
-    Plugin's license.
+    License of the plugin.
     @endparblock
 
 @bt_pre_not_null{_license}
@@ -546,27 +542,28 @@ See the \ref api-plugin-prop-version "version" property.
     @parblock
     <code>unsigned int</code>
 
-    Plugin's major version.
+    Major version of the plugin.
     @endparblock
 @param[in] _minor
     @parblock
     <code>unsigned int</code>
 
-    Plugin's minor version.
+    Minor version of the plugin.
     @endparblock
 @param[in] _patch
     @parblock
     <code>unsigned int</code>
 
-    Plugin's patch version.
+    Patch version of the plugin.
     @endparblock
 @param[in] _extra
     @parblock
     <code>const char *</code>
 
-    Plugin's version's extra information.
+    Extra information of the version of the plugin.
 
-    Can be \c NULL if the plugin's version has no extra information.
+    Can be \c NULL if the version of the plugin has no
+    extra information.
     @endparblock
 */
 #define BT_PLUGIN_VERSION_WITH_ID(_id, _major, _minor, _patch, _extra) \
@@ -651,7 +648,7 @@ typedef bt_plugin_initialize_func_status (*bt_plugin_initialize_func)(
     @parblock
     #bt_plugin_initialize_func
 
-    Plugin's initialization function.
+    Initialization function of the plugin.
     @endparblock
 
 @bt_pre_not_null{_func}
@@ -687,7 +684,7 @@ typedef void (*bt_plugin_finalize_func)(void);
     @parblock
     #bt_plugin_finalize_func
 
-    Plugin's finalization function.
+    Finalization function of the plugin.
     @endparblock
 
 @bt_pre_not_null{_func}
@@ -712,8 +709,9 @@ typedef void (*bt_plugin_finalize_func)(void);
 /*!
 @brief
     Adds a \bt_src_comp_cls named \bt_p{_name}, having the ID
-    \bt_p{_component_class_id} and the message iterator class's "next"
-    method \bt_p{_message_iterator_class_next_method}, to the plugin
+    \bt_p{_component_class_id} and the
+    "next" method \bt_p{_message_iterator_class_next_method} of
+    the message iterator class, to the plugin
     having the ID \bt_p{_plugin_id}.
 
 @param[in] _plugin_id
@@ -726,21 +724,22 @@ typedef void (*bt_plugin_finalize_func)(void);
     @parblock
     C identifier.
 
-    Source component class's ID, unique amongst all the source component
-    class IDs of the same plugin.
+    ID of the source component class, unique amongst all the source
+    component class IDs of the same plugin.
     @endparblock
 @param[in] _name
     @parblock
     <code>const char *</code>
 
-    Source component class's name, unique amongst all the source
+    Name of the source component class, unique amongst all the source
     component class names of the same plugin.
     @endparblock
 @param[in] _message_iterator_class_next_method
     @parblock
     #bt_message_iterator_class_next_method
 
-    Source component class's message iterator class's "next" method.
+    "Next" method of the message iterator class of the source component
+    class.
     @endparblock
 
 @bt_pre_not_null{_name}
@@ -777,9 +776,9 @@ typedef void (*bt_plugin_finalize_func)(void);
 /*!
 @brief
     Adds a \bt_flt_comp_cls named \bt_p{_name}, having the ID
-    \bt_p{_component_class_id} and the message iterator class's "next"
-    method \bt_p{_message_iterator_class_next_method}, to the plugin
-    having the ID \bt_p{_plugin_id}.
+    \bt_p{_component_class_id} and the "next"
+    method \bt_p{_message_iterator_class_next_method} of the message
+    iterator class, to the plugin having the ID \bt_p{_plugin_id}.
 
 @param[in] _plugin_id
     @parblock
@@ -791,21 +790,22 @@ typedef void (*bt_plugin_finalize_func)(void);
     @parblock
     C identifier.
 
-    Filter component class's ID, unique amongst all the filter component
-    class IDs of the same plugin.
+    ID of the filter component class, unique amongst all the filter
+    component class IDs of the same plugin.
     @endparblock
 @param[in] _name
     @parblock
     <code>const char *</code>
 
-    Filter component class's name, unique amongst all the filter
+    Name of the filter component class, unique amongst all the filter
     component class names of the same plugin.
     @endparblock
 @param[in] _message_iterator_class_next_method
     @parblock
     #bt_message_iterator_class_next_method
 
-    Filter component class's message iterator class's "next" method.
+    "Next" method of the message iterator class of the filter component
+    class.
     @endparblock
 
 @bt_pre_not_null{_name}
@@ -856,21 +856,22 @@ typedef void (*bt_plugin_finalize_func)(void);
     @parblock
     C identifier.
 
-    Sink component class's ID, unique amongst all the sink component
-    class IDs of the same plugin.
+    ID of the sink component class, unique amongst all the sink
+    component class IDs of the same plugin.
     @endparblock
 @param[in] _name
     @parblock
     <code>const char *</code>
 
-    Sink component class's name, unique amongst all the sink
+    Name of the sink component class, unique amongst all the sink
     component class names of the same plugin.
     @endparblock
 @param[in] _consume_method
     @parblock
     #bt_component_class_sink_consume_method
 
-    Sink component class's message iterator class's "next" method.
+    "Next" method of the message iterator class of the sink component
+    class.
     @endparblock
 
 @bt_pre_not_null{_name}
@@ -938,7 +939,7 @@ See the \ref api-comp-cls-prop-descr "description" property.
     @parblock
     <code>const char *</code>
 
-    Source component class's description.
+    Description of the source component class.
     @endparblock
 
 @bt_pre_not_null{_description}
@@ -982,7 +983,7 @@ See the \ref api-comp-cls-prop-help "help text" property.
     @parblock
     <code>const char *</code>
 
-    Source component class's help text.
+    Help text of the source component class.
     @endparblock
 
 @bt_pre_not_null{_help_text}
@@ -1033,7 +1034,7 @@ See the \ref api-comp-cls-prop-descr "description" property.
     @parblock
     <code>const char *</code>
 
-    Filter component class's description.
+    Description of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_description}
@@ -1077,7 +1078,7 @@ See the \ref api-comp-cls-prop-help "help text" property.
     @parblock
     <code>const char *</code>
 
-    Filter component class's help text.
+    Help text of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_help_text}
@@ -1128,7 +1129,7 @@ See the \ref api-comp-cls-prop-descr "description" property.
     @parblock
     <code>const char *</code>
 
-    Sink component class's description.
+    Description of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_description}
@@ -1172,7 +1173,7 @@ See the \ref api-comp-cls-prop-help "help text" property.
     @parblock
     <code>const char *</code>
 
-    Sink component class's help text.
+    Help text of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_help_text}
@@ -1223,7 +1224,7 @@ See the \ref api-comp-cls-dev-meth-fini "finalize" method.
     @parblock
     #bt_component_class_source_finalize_method
 
-    Source component class's finalization method.
+    Finalization method of the source component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1269,7 +1270,7 @@ method.
     @parblock
     #bt_component_class_source_get_supported_mip_versions_method
 
-    Source component class's "get supported MIP versions" method.
+    "Get supported MIP versions" method of the source component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1314,7 +1315,7 @@ See the \ref api-comp-cls-dev-meth-init "initialize" method.
     @parblock
     #bt_component_class_source_initialize_method
 
-    Source component class's initialization method.
+    Initialization method of the source component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1359,7 +1360,8 @@ See the \ref api-msg-iter-cls-meth-fini "finalize" method.
     @parblock
     #bt_message_iterator_class_finalize_method
 
-    Source component class's message iterator class's finalization method.
+    Finalization method of the message iterator class of the source
+    component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1404,8 +1406,8 @@ See the \ref api-msg-iter-cls-meth-init "initialize" method.
     @parblock
     #bt_message_iterator_class_initialize_method
 
-    Source component class's message iterator class's initialization
-    method.
+    Initialization method of the message iterator class of the source
+    component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1455,17 +1457,17 @@ See the \ref api-msg-iter-cls-meth-seek-beg "seek beginning" and
     @parblock
     #bt_message_iterator_class_seek_beginning_method
 
-    Source component class's message iterator class's "seek beginning"
-    method.
+    "Seek beginning" method of the message iterator class of the source
+    component class.
     @endparblock
 @param[in] _can_seek_method
     @parblock
     #bt_message_iterator_class_can_seek_beginning_method
 
-    Source component class's message iterator class's
-    "can seek beginning?" method.
+    "Can seek beginning?" method of the message iterator class of the
+    source component class.
 
-    Can be \c NULL, in which case it is equivalent to setting a method
+    Can be \c NULL, in which case it's equivalent to setting a method
     which always returns #BT_TRUE.
     @endparblock
 
@@ -1519,17 +1521,17 @@ methods.
     @parblock
     #bt_message_iterator_class_seek_ns_from_origin_method
 
-    Source component class's message iterator class's "seek ns from
-    origin" method.
+    "Seek ns from origin" method of the message iterator class of the
+    source component class.
     @endparblock
 @param[in] _can_seek_method
     @parblock
     #bt_message_iterator_class_can_seek_ns_from_origin_method
 
-    Source component class's message iterator class's "can seek ns from
-    origin?" method.
+    "Can seek ns from origin?" method of the message iterator class of
+    the source component class.
 
-    Can be \c NULL, in which case it is equivalent to setting a method
+    Can be \c NULL, in which case it's equivalent to setting a method
     which always returns #BT_TRUE.
     @endparblock
 
@@ -1579,7 +1581,7 @@ method.
     @parblock
     #bt_component_class_source_output_port_connected_method
 
-    Source component class's "output port connected" method.
+    "Output port connected" method of the source component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1624,7 +1626,7 @@ See the \ref api-comp-cls-dev-meth-query "query" method.
     @parblock
     #bt_component_class_source_query_method
 
-    Source component class's query method.
+    Query method of the source component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1676,7 +1678,7 @@ See the \ref api-comp-cls-dev-meth-fini "finalize" method.
     @parblock
     #bt_component_class_filter_finalize_method
 
-    Filter component class's finalization method.
+    Finalization method of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1722,7 +1724,7 @@ method.
     @parblock
     #bt_component_class_filter_get_supported_mip_versions_method
 
-    Filter component class's "get supported MIP versions" method.
+    "Get supported MIP versions" method of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1767,7 +1769,7 @@ See the \ref api-comp-cls-dev-meth-init "initialize" method.
     @parblock
     #bt_component_class_filter_initialize_method
 
-    Filter component class's initialization method.
+    Initialization method of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1814,7 +1816,7 @@ method.
     @parblock
     #bt_component_class_filter_input_port_connected_method
 
-    Filter component class's "input port connected" method.
+    "Input port connected" method of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1859,7 +1861,8 @@ See the \ref api-msg-iter-cls-meth-fini "finalize" method.
     @parblock
     #bt_message_iterator_class_finalize_method
 
-    Filter component class's message iterator class's finalization method.
+    Finalization method of the message iterator class of the filter
+    component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1904,8 +1907,8 @@ See the \ref api-msg-iter-cls-meth-init "initialize" method.
     @parblock
     #bt_message_iterator_class_initialize_method
 
-    Filter component class's message iterator class's initialization
-    method.
+    Initialization method of the message iterator class of the filter
+    component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -1955,17 +1958,17 @@ See the \ref api-msg-iter-cls-meth-seek-beg "seek beginning" and
     @parblock
     #bt_message_iterator_class_seek_beginning_method
 
-    Filter component class's message iterator class's "seek beginning"
-    method.
+    "Seek beginning" method of the message iterator class of the filter
+    component class.
     @endparblock
 @param[in] _can_seek_method
     @parblock
     #bt_message_iterator_class_can_seek_beginning_method
 
-    Filter component class's message iterator class's
-    "can seek beginning?" method.
+    "Can seek beginning?" method of the message iterator class of the
+    filter component class.
 
-    Can be \c NULL, in which case it is equivalent to setting a method
+    Can be \c NULL, in which case it's equivalent to setting a method
     which always returns #BT_TRUE.
     @endparblock
 
@@ -2019,17 +2022,17 @@ methods.
     @parblock
     #bt_message_iterator_class_seek_ns_from_origin_method
 
-    Filter component class's message iterator class's "seek ns from
-    origin" method.
+    "Seek ns from origin" method of the message iterator class of the
+    filter component class.
     @endparblock
 @param[in] _can_seek_method
     @parblock
     #bt_message_iterator_class_can_seek_ns_from_origin_method
 
-    Filter component class's message iterator class's "can seek ns from
-    origin?" method.
+    "Can seek ns from origin?" method of the message iterator class of
+    the filter component class.
 
-    Can be \c NULL, in which case it is equivalent to setting a method
+    Can be \c NULL, in which case it's equivalent to setting a method
     which always returns #BT_TRUE.
     @endparblock
 
@@ -2079,7 +2082,7 @@ method.
     @parblock
     #bt_component_class_filter_output_port_connected_method
 
-    Filter component class's "output port connected" method.
+    "Output port connected" method of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2124,7 +2127,7 @@ See the \ref api-comp-cls-dev-meth-query "query" method.
     @parblock
     #bt_component_class_filter_query_method
 
-    Filter component class's query method.
+    Query method of the filter component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2176,7 +2179,7 @@ See the \ref api-comp-cls-dev-meth-fini "finalize" method.
     @parblock
     #bt_component_class_sink_finalize_method
 
-    Sink component class's finalization method.
+    Finalization method of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2222,7 +2225,7 @@ method.
     @parblock
     #bt_component_class_sink_get_supported_mip_versions_method
 
-    Sink component class's "get supported MIP versions" method.
+    "Get supported MIP versions" method of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2269,7 +2272,7 @@ method.
     @parblock
     #bt_component_class_sink_graph_is_configured_method
 
-    Sink component class's "graph is configured" method.
+    "Graph is configured" method of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2314,7 +2317,7 @@ See the \ref api-comp-cls-dev-meth-init "initialize" method.
     @parblock
     #bt_component_class_sink_initialize_method
 
-    Sink component class's initialization method.
+    Initialization method of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2361,7 +2364,7 @@ method.
     @parblock
     #bt_component_class_sink_input_port_connected_method
 
-    Sink component class's "input port connected" method.
+    "Input port connected" method of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2406,7 +2409,7 @@ See the \ref api-comp-cls-dev-meth-query "query" method.
     @parblock
     #bt_component_class_sink_query_method
 
-    Sink component class's query method.
+    Query method of the sink component class.
     @endparblock
 
 @bt_pre_not_null{_method}
@@ -2430,7 +2433,7 @@ See the \ref api-comp-cls-dev-meth-query "query" method.
 
 /* Plugin descriptor: describes a single plugin (internal use) */
 struct __bt_plugin_descriptor {
-	/* Plugin's name */
+	/* Name of the plugin */
 	const char *name;
 } __attribute__((packed));
 
@@ -2457,13 +2460,13 @@ struct __bt_plugin_descriptor_attribute {
 	/* Plugin descriptor to which to associate this attribute */
 	const struct __bt_plugin_descriptor *plugin_descriptor;
 
-	/* Name of the attribute's type for debug purposes */
+	/* Name of the type of the attribute for debug purposes */
 	const char *type_name;
 
-	/* Attribute's type */
+	/* Type of the attribute */
 	enum __bt_plugin_descriptor_attribute_type type;
 
-	/* Attribute's value (depends on attribute's type) */
+	/* Value of the attribute (depends on the type of attribute) */
 	union {
 		/* BT_PLUGIN_DESCRIPTOR_ATTRIBUTE_TYPE_INIT */
 		bt_plugin_initialize_func init;
@@ -2545,13 +2548,13 @@ struct __bt_plugin_component_class_descriptor_attribute {
 	 */
 	const struct __bt_plugin_component_class_descriptor *comp_class_descriptor;
 
-	/* Name of the attribute's type for debug purposes */
+	/* Name of the type of the attribute for debug purposes */
 	const char *type_name;
 
-	/* Attribute's type */
+	/* Type of the attribute */
 	enum __bt_plugin_component_class_descriptor_attribute_type type;
 
-	/* Attribute's value (depends on attribute's type) */
+	/* Value of the attribute (depends on the type of attribute) */
 	union {
 		/* BT_PLUGIN_COMPONENT_CLASS_DESCRIPTOR_ATTRIBUTE_TYPE_DESCRIPTION */
 		const char *description;
@@ -2664,7 +2667,7 @@ struct __bt_plugin_component_class_descriptor_attribute const * const *__bt_get_
  * Clang supports the no_sanitize variable attribute on global variables.
  * GCC only supports the no_sanitize_address function attribute, which is
  * not what we need. This is fine because, as far as we have seen, gcc
- * does not insert red zones around global variables.
+ * doesn't insert red zones around global variables.
  */
 #if defined(__clang__)
 # if __has_feature(address_sanitizer)
