@@ -1,27 +1,13 @@
+/*
+ * SPDX-License-Identifier: MIT
+ *
+ * Copyright (C) 2010-2019 EfficiOS Inc. and Linux Foundation
+ */
+
 #ifndef BABELTRACE2_TRACE_IR_FIELD_H
 #define BABELTRACE2_TRACE_IR_FIELD_H
 
-/*
- * Copyright (c) 2010-2019 EfficiOS Inc. and Linux Foundation
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
+/* IWYU pragma: private, include <babeltrace2/babeltrace.h> */
 
 #ifndef __BT_IN_BABELTRACE_H
 # error "Please include <babeltrace2/babeltrace.h> instead."
@@ -42,7 +28,7 @@ extern "C" {
 @brief
     Containers of trace data.
 
-<strong><em>Fields</em></strong> are containers of trace data: they are
+<strong><em>Fields</em></strong> are containers of trace data: they're
 found in \bt_p_ev and \bt_p_pkt.
 
 Fields are instances of \bt_p_fc:
@@ -70,6 +56,7 @@ categories:
     - \ref api-tir-field-enum "Enumeration" (unsigned and signed)
     - \ref api-tir-field-real "Real" (single-precision and double-precision)
     - \ref api-tir-field-string "String"
+    - \ref api-tir-field-blob "BLOB" (static and dynamic; \bt_avail_since{1})
   </dd>
 
   <dt>Container</dt>
@@ -91,7 +78,7 @@ You cannot directly create a field: there are no
 <code>bt_field_*_create()</code> functions. The \bt_name library
 creates fields within an \bt_ev or a \bt_pkt from \bt_p_fc.
 Therefore, to fill the payload fields of an \bt_ev, you must first
-borrow the event's existing payload \bt_struct_field with
+borrow the existing payload \bt_struct_field of the event with
 bt_event_borrow_payload_field() and then borrow each field, recursively,
 to set their values.
 
@@ -140,9 +127,10 @@ postcondition.
 
 All the field types share the same C type, #bt_field.
 
-Get the type enumerator of a field's class with bt_field_get_class_type().
-Get whether or not a field class type conceptually \em is a given type
-with the inline bt_field_class_type_is() function.
+Get the type enumerator of the class of a field with
+bt_field_get_class_type(). Get whether or not a field class type
+conceptually \em is a given type with the inline
+bt_field_class_type_is() function.
 
 <h1>\anchor api-tir-field-bool Boolean field</h1>
 
@@ -162,7 +150,7 @@ A bit array field contains a fixed-length array of bits. Its length
 is \ref api-tir-fc-ba-prop-len "given by its class".
 
 The bit array field API interprets the array as an unsigned integer
-value: the least significant bit's index is 0.
+value: the index of the least significant bit is&nbsp;0.
 
 For example, to get whether or not bit&nbsp;3 of a bit array field is
 set:
@@ -170,7 +158,7 @@ set:
 @code
 uint64_t value = bt_field_bit_array_get_value_as_integer(field);
 
-if (value & (UINT64_C(1) << UINT64_C(3))) {
+if (value & (UINT64_C(1) << 3)) {
     // Bit 3 is set
 }
 @endcode
@@ -181,6 +169,11 @@ bt_field_bit_array_set_value_as_integer().
 Get the bits of a bit array field with
 bt_field_bit_array_get_value_as_integer().
 
+Since Babeltrace&nbsp;2.1, get the labels of all the
+active \ref api-tir-fc-ba-prop-flags "flags"
+of the \ref api-tir-fc-ba "class" of a bit array field for the set bits
+of its integral value with bt_field_bit_array_get_active_flag_labels().
+
 <h1>\anchor api-tir-field-int Integer fields</h1>
 
 <strong><em>Integer fields</em></strong> are \bt_int_fc instances.
@@ -320,11 +313,53 @@ bt_field_string_get_value().
 Get the length of a string field with
 bt_field_string_get_length().
 
-Append a string to a string field's current value with
+Append a string to the current value of a string field with
 bt_field_string_append() and bt_field_string_append_with_length().
 
 Clear a string field with bt_field_string_clear().
 
+<h1>\anchor api-tir-field-blob BLOB fields (\bt_avail_since{1})</h1>
+
+<strong><em>BLOB fields</em></strong> are \bt_blob_fc instances.
+
+BLOB fields contain zero or more bytes of binary data.
+
+@note
+    BLOB fields are only available when the \bt_trace_cls from
+    which you create their classes was created from a \bt_comp
+    which belongs to a trace processing \bt_graph with the effective
+    \bt_mip version&nbsp;1 (\bt_avail_since{1}).
+
+A BLOB field is an \em abstract field. The concrete BLOB fields are:
+
+<dl>
+  <dt>Static BLOB field</dt>
+  <dd>
+    A \bt_sblob_fc instance.
+
+    A static BLOB field contains a fixed number of bytes. Its length
+    is \ref api-tir-fc-sblob-prop-len "given by its class".
+  </dd>
+
+  <dt>Dynamic BLOB field</dt>
+  <dd>
+    A \bt_dblob_fc instance.
+
+    A dynamic BLOB field contains a variable number of bytes, that is,
+    each instance of the same dynamic BLOB field class can contain a
+    different number of bytes.
+
+    Set the length of a dynamic BLOB field with
+    bt_field_blob_dynamic_set_length() before you get its data
+    with bt_field_blob_get_data().
+  </dd>
+</dl>
+
+Get the length of a BLOB field with bt_field_blob_get_length().
+
+Get the data of a BLOB field with bt_field_blob_get_data()
+or bt_field_blob_get_data_const().
+
 <h1>\anchor api-tir-field-array Array fields</h1>
 
 <strong><em>Array fields</em></strong> are \bt_array_fc instances.
@@ -342,7 +377,7 @@ An array field is an \em abstract field. The concrete array fields are:
     is \ref api-tir-fc-sarray-prop-len "given by its class".
   </dd>
 
-  <dt>Dynamic array field class</dt>
+  <dt>Dynamic array field</dt>
   <dd>
     A \bt_darray_fc instance.
 
@@ -350,13 +385,13 @@ An array field is an \em abstract field. The concrete array fields are:
     each instance of the same dynamic array field class can contain a
     different number of elements.
 
-    Set a dynamic array field's length with
+    Set the length of a dynamic array field with
     bt_field_array_dynamic_set_length() before you borrow any of its
     fields.
   </dd>
 </dl>
 
-Get an array field's length with bt_field_array_get_length().
+Get the length of an array field with bt_field_array_get_length().
 
 Borrow a field from an array field at a given index with
 bt_field_array_borrow_element_field_by_index() and
@@ -370,11 +405,11 @@ A structure field contains an ordered list of zero or more members. A
 structure field member contains a field: it's an instance of a structure
 field class member.
 
-Borrow a member's field from a structure field at a given index with
-bt_field_structure_borrow_member_field_by_index() and
+Borrow the field of a member from a structure field at a given index
+with bt_field_structure_borrow_member_field_by_index() and
 bt_field_structure_borrow_member_field_by_index_const().
 
-Borrow a member's field from a structure field by name with
+Borrow the field of a member from a structure field by name with
 bt_field_structure_borrow_member_field_by_name() and
 bt_field_structure_borrow_member_field_by_name_const().
 
@@ -402,15 +437,15 @@ instance of a variant field class option.
 Set the current option of a variant field with
 bt_field_variant_select_option_by_index().
 
-Get a variant field's selected option's index with
+Get the selected option index of a variant field with
 bt_field_variant_get_selected_option_index().
 
-Borrow a variant field's selected option's field with
+Borrow the field of the selected option of a variant field with
 bt_field_variant_borrow_selected_option_field() and
 bt_field_variant_borrow_selected_option_field_const().
 
-Borrow the class of a variant field's selected
-option with bt_field_variant_borrow_selected_option_class_const(),
+Borrow the class of the selected option of a variant field with
+bt_field_variant_borrow_selected_option_class_const(),
 bt_field_variant_with_selector_field_integer_unsigned_borrow_selected_option_class_const(),
 and
 bt_field_variant_with_selector_field_integer_signed_borrow_selected_option_class_const().
@@ -447,7 +482,7 @@ bt_field_class_get_type(bt_field_borrow_class(field))
 @endcode
 
 @param[in] field
-    Field of which to get the class's type enumerator
+    Field of which to get the type enumerator of its class.
 
 @returns
     Type enumerator of the class of \bt_p{field}.
@@ -458,7 +493,7 @@ bt_field_class_get_type(bt_field_borrow_class(field))
     Returns the type enumerator of a \bt_fc.
 */
 extern bt_field_class_type bt_field_get_class_type(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -482,7 +517,7 @@ extern bt_field_class_type bt_field_get_class_type(
 @sa bt_field_borrow_class_const() &mdash;
     \c const version of this function.
 */
-extern bt_field_class *bt_field_borrow_class(bt_field *field);
+extern bt_field_class *bt_field_borrow_class(bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -492,7 +527,7 @@ extern bt_field_class *bt_field_borrow_class(bt_field *field);
 See bt_field_borrow_class().
 */
 extern const bt_field_class *bt_field_borrow_class_const(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -518,7 +553,8 @@ extern const bt_field_class *bt_field_borrow_class_const(
 @sa bt_field_bool_get_value() &mdash;
     Returns the value of a boolean field.
 */
-extern void bt_field_bool_set_value(bt_field *field, bt_bool value);
+extern void bt_field_bool_set_value(bt_field *field, bt_bool value)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -536,7 +572,7 @@ extern void bt_field_bool_set_value(bt_field *field, bt_bool value);
 @sa bt_field_bool_set_value() &mdash;
     Sets the value of a boolean field.
 */
-extern bt_bool bt_field_bool_get_value(const bt_field *field);
+extern bt_bool bt_field_bool_get_value(const bt_field *field) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -550,7 +586,7 @@ extern bt_bool bt_field_bool_get_value(const bt_field *field);
     Sets the bits of the \bt_ba_field \bt_p{field} to the bits of
     \bt_p{bits}.
 
-The least significant bit's index is 0.
+The index of the least significant bit is&nbsp;0.
 
 See \bt_c_ba_field to learn more.
 
@@ -567,14 +603,14 @@ See \bt_c_ba_field to learn more.
     Returns the bits of a bit array field as an integer.
 */
 extern void bt_field_bit_array_set_value_as_integer(bt_field *field,
-		uint64_t bits);
+		uint64_t bits) __BT_NOEXCEPT;
 
 /*!
 @brief
     Returns the bits of the \bt_ba_field \bt_p{field} as an
     unsigned integer.
 
-The least significant bit's index is 0.
+The index of the least significant bit is&nbsp;0.
 
 See \bt_c_ba_field to learn more.
 
@@ -591,7 +627,72 @@ See \bt_c_ba_field to learn more.
     Sets the bits of a bit array field from an integer.
 */
 extern uint64_t bt_field_bit_array_get_value_as_integer(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
+
+/*!
+@brief
+    Status codes for
+    bt_field_bit_array_get_active_flag_labels().
+
+@bt_since{1}
+*/
+typedef enum bt_field_bit_array_get_active_flag_labels_status {
+	/*!
+	@brief
+	    Success.
+	*/
+	BT_FIELD_BIT_ARRAY_GET_ACTIVE_FLAG_LABELS_STATUS_OK		= __BT_FUNC_STATUS_OK,
+
+	/*!
+	@brief
+	    Out of memory.
+	*/
+	BT_FIELD_BIT_ARRAY_GET_ACTIVE_FLAG_LABELS_STATUS_MEMORY_ERROR	= __BT_FUNC_STATUS_MEMORY_ERROR,
+} bt_field_bit_array_get_active_flag_labels_status;
+
+/*!
+@brief
+    Returns the labels of all the active flags of the
+    \ref api-tir-fc-ba "class" of the \bt_ba_field \bt_p{field}
+    for the set bits of the integral value of \bt_p{field}.
+
+This function returns
+
+@code
+(bt_field_bit_array_get_active_flag_labels_status)
+bt_field_class_bit_array_get_active_flag_labels_for_value_as_integer(
+    bt_field_borrow_class_const(field),
+    bt_field_bit_array_get_value_as_integer(field),
+    labels, count)
+@endcode
+
+@param[in] field
+    Bit array field having the class from which to get the labels of the
+    active flags for the integral value of \bt_p{field}.
+@param[out] labels
+    See
+    bt_field_class_bit_array_get_active_flag_labels_for_value_as_integer().
+@param[out] count
+    See
+    bt_field_class_bit_array_get_active_flag_labels_for_value_as_integer().
+
+@retval #BT_FIELD_BIT_ARRAY_GET_ACTIVE_FLAG_LABELS_STATUS_OK
+    Success.
+@retval #BT_FIELD_BIT_ARRAY_GET_ACTIVE_FLAG_LABELS_STATUS_MEMORY_ERROR
+    Out of memory.
+
+@bt_since{1}
+
+@bt_pre_not_null{field}
+@bt_pre_is_ba_field{field}
+@bt_pre_field_with_mip{field, 1}
+@bt_pre_not_null{labels}
+@bt_pre_not_null{count}
+*/
+extern bt_field_bit_array_get_active_flag_labels_status
+bt_field_bit_array_get_active_flag_labels(const bt_field *field,
+	bt_field_class_bit_array_flag_label_array *labels,
+	uint64_t *count) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -622,7 +723,7 @@ extern uint64_t bt_field_bit_array_get_value_as_integer(
     Returns the value of an unsigned integer field.
 */
 extern void bt_field_integer_unsigned_set_value(bt_field *field,
-		uint64_t value);
+		uint64_t value) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -641,7 +742,7 @@ extern void bt_field_integer_unsigned_set_value(bt_field *field,
     Sets the value of an unsigned integer field.
 */
 extern uint64_t bt_field_integer_unsigned_get_value(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -665,7 +766,7 @@ extern uint64_t bt_field_integer_unsigned_get_value(
     Returns the value of an signed integer field.
 */
 extern void bt_field_integer_signed_set_value(bt_field *field,
-		int64_t value);
+		int64_t value) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -683,7 +784,8 @@ extern void bt_field_integer_signed_set_value(bt_field *field,
 @sa bt_field_integer_signed_set_value() &mdash;
     Sets the value of an signed integer field.
 */
-extern int64_t bt_field_integer_signed_get_value(const bt_field *field);
+extern int64_t bt_field_integer_signed_get_value(
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -753,7 +855,7 @@ bt_field_class_enumeration_unsigned_get_mapping_labels_for_value(
 extern bt_field_enumeration_get_mapping_labels_status
 bt_field_enumeration_unsigned_get_mapping_labels(const bt_field *field,
 		bt_field_class_enumeration_mapping_label_array *labels,
-		uint64_t *count);
+		uint64_t *count) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -796,7 +898,7 @@ bt_field_class_enumeration_signed_get_mapping_labels_for_value(
 extern bt_field_enumeration_get_mapping_labels_status
 bt_field_enumeration_signed_get_mapping_labels(const bt_field *field,
 		bt_field_class_enumeration_mapping_label_array *labels,
-		uint64_t *count);
+		uint64_t *count) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -824,7 +926,7 @@ bt_field_enumeration_signed_get_mapping_labels(const bt_field *field,
     Returns the value of a single-precision real field.
 */
 extern void bt_field_real_single_precision_set_value(bt_field *field,
-		float value);
+		float value) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -842,7 +944,8 @@ extern void bt_field_real_single_precision_set_value(bt_field *field,
 @sa bt_field_real_single_precision_set_value() &mdash;
     Sets the value of a single-precision real field.
 */
-extern float bt_field_real_single_precision_get_value(const bt_field *field);
+extern float bt_field_real_single_precision_get_value(
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -863,7 +966,7 @@ extern float bt_field_real_single_precision_get_value(const bt_field *field);
     Returns the value of a double-precision real field.
 */
 extern void bt_field_real_double_precision_set_value(bt_field *field,
-		double value);
+		double value) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -881,7 +984,8 @@ extern void bt_field_real_double_precision_set_value(bt_field *field,
 @sa bt_field_real_double_precision_set_value() &mdash;
     Sets the value of a double-precision real field.
 */
-extern double bt_field_real_double_precision_get_value(const bt_field *field);
+extern double bt_field_real_double_precision_get_value(
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -936,7 +1040,7 @@ typedef enum bt_field_string_set_value_status {
     Clears a string field.
 */
 extern bt_field_string_set_value_status bt_field_string_set_value(
-		bt_field *field, const char *value);
+		bt_field *field, const char *value) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -951,7 +1055,7 @@ extern bt_field_string_set_value_status bt_field_string_set_value(
 @bt_pre_not_null{field}
 @bt_pre_is_string_field{field}
 */
-extern uint64_t bt_field_string_get_length(const bt_field *field);
+extern uint64_t bt_field_string_get_length(const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -973,7 +1077,8 @@ extern uint64_t bt_field_string_get_length(const bt_field *field);
 @sa bt_field_string_set_value() &mdash;
     Sets the value of a string field.
 */
-extern const char *bt_field_string_get_value(const bt_field *field);
+extern const char *bt_field_string_get_value(
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1000,7 +1105,7 @@ typedef enum bt_field_string_append_status {
     the \bt_string_field \bt_p{field}.
 
 @attention
-    If you didn't set the value of \bt_p{field} yet, you must call
+    If you didn't set the value of \bt_p{field} yet, then you must call
     bt_field_string_clear() before you call this function.
 
 @param[in] field
@@ -1024,7 +1129,7 @@ typedef enum bt_field_string_append_status {
     Sets the value of a string field.
 */
 extern bt_field_string_append_status bt_field_string_append(
-		bt_field *field, const char *value);
+		bt_field *field, const char *value) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1033,7 +1138,7 @@ extern bt_field_string_append_status bt_field_string_append(
     \bt_p{field}.
 
 @attention
-    If you didn't set the value of \bt_p{field} yet, you must call
+    If you didn't set the value of \bt_p{field} yet, then you must call
     bt_field_string_clear() before you call this function.
 
 @param[in] field
@@ -1061,7 +1166,8 @@ extern bt_field_string_append_status bt_field_string_append(
     Sets the value of a string field.
 */
 extern bt_field_string_append_status bt_field_string_append_with_length(
-		bt_field *field, const char *value, uint64_t length);
+		bt_field *field, const char *value, uint64_t length)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1078,7 +1184,133 @@ extern bt_field_string_append_status bt_field_string_append_with_length(
 @sa bt_field_string_set_value() &mdash;
     Sets the value of a string field.
 */
-extern void bt_field_string_clear(bt_field *field);
+extern void bt_field_string_clear(bt_field *field) __BT_NOEXCEPT;
+
+/*! @} */
+
+/*!
+@name BLOB field (\bt_avail_since{1})
+@{
+*/
+
+/*!
+@brief
+    Returns the length (number of bytes) of the \bt_blob_field \bt_p{field}.
+
+@param[in] field
+    BLOB field of which to get the length.
+
+@returns
+    Length of \bt_p{field}.
+
+@bt_since{1}
+
+@bt_pre_not_null{field}
+@bt_pre_is_blob_field{field}
+@bt_pre_field_with_mip{field, 1}
+*/
+extern uint64_t bt_field_blob_get_length(const bt_field *field);
+
+/*!
+@brief
+    Returns the writable data of the \bt_blob_field \bt_p{field}.
+
+@attention
+    If \bt_p{field} is a dynamic BLOB field, then it must have a length
+    (call bt_field_blob_dynamic_set_length()) before you call this
+    function.
+
+@param[in] field
+    BLOB field from which to get the writable data.
+
+@returns
+    @parblock
+    Writable data of \bt_p{field}.
+
+    The returned pointer remains valid until \bt_p{field} is modified.
+    @endparblock
+
+@bt_since{1}
+
+@bt_pre_not_null{field}
+@bt_pre_is_blob_field{field}
+@bt_pre_hot{field}
+@bt_pre_field_with_mip{field, 1}
+
+@sa bt_field_blob_get_data_const() &mdash;
+    Returns the readable data of a BLOB field.
+*/
+extern uint8_t *bt_field_blob_get_data(bt_field *field);
+
+/*!
+@brief
+    Returns the readable data of the \bt_blob_field \bt_p{field}.
+
+@param[in] field
+    BLOB field from which to get the readable data.
+
+@returns
+    @parblock
+    Readable data of \bt_p{field}.
+
+    The returned pointer remains valid until \bt_p{field} is modified.
+    @endparblock
+
+@bt_since{1}
+
+@bt_pre_not_null{field}
+@bt_pre_is_blob_field{field}
+@bt_pre_field_with_mip{field, 1}
+
+@sa bt_field_blob_get_data() &mdash;
+    Returns the writable data of a BLOB field.
+*/
+extern const uint8_t *bt_field_blob_get_data_const(const bt_field *field);
+
+/*!
+@brief
+    Status codes for bt_field_blob_dynamic_set_length().
+
+@bt_since{1}
+*/
+typedef enum bt_field_blob_dynamic_set_length_status {
+	/*!
+	@brief
+	    Success.
+	*/
+	BT_FIELD_DYNAMIC_BLOB_SET_LENGTH_STATUS_OK		= __BT_FUNC_STATUS_OK,
+
+	/*!
+	@brief
+	    Out of memory.
+	*/
+	BT_FIELD_DYNAMIC_BLOB_SET_LENGTH_STATUS_MEMORY_ERROR	= __BT_FUNC_STATUS_MEMORY_ERROR,
+} bt_field_blob_dynamic_set_length_status;
+
+/*!
+@brief
+    Sets the length (number of bytes) of the
+    \bt_dblob_field \bt_p{field}.
+
+@param[in] field
+    Dynamic BLOB field of which to set the length (number of bytes).
+@param[in] length
+    New length of \bt_p{field}.
+
+@retval #BT_FIELD_DYNAMIC_BLOB_SET_LENGTH_STATUS_OK
+    Success.
+@retval #BT_FIELD_DYNAMIC_BLOB_SET_LENGTH_STATUS_MEMORY_ERROR
+    Out of memory.
+
+@bt_since{1}
+
+@bt_pre_not_null{field}
+@bt_pre_is_dblob_field{field}
+@bt_pre_hot{field}
+@bt_pre_field_with_mip{field, 1}
+*/
+extern bt_field_blob_dynamic_set_length_status bt_field_blob_dynamic_set_length(
+		bt_field *field, uint64_t length);
 
 /*! @} */
 
@@ -1100,7 +1332,7 @@ extern void bt_field_string_clear(bt_field *field);
 @bt_pre_not_null{field}
 @bt_pre_is_array_field{field}
 */
-extern uint64_t bt_field_array_get_length(const bt_field *field);
+extern uint64_t bt_field_array_get_length(const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1108,7 +1340,7 @@ extern uint64_t bt_field_array_get_length(const bt_field *field);
     \bt_p{field}.
 
 @attention
-    If \bt_p{field} is a dynamic array field, it must have a length
+    If \bt_p{field} is a dynamic array field, then it must have a length
     (call bt_field_array_dynamic_set_length()) before you call this
     function.
 
@@ -1135,7 +1367,7 @@ extern uint64_t bt_field_array_get_length(const bt_field *field);
     \c const version of this function.
 */
 extern bt_field *bt_field_array_borrow_element_field_by_index(
-		bt_field *field, uint64_t index);
+		bt_field *field, uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1146,7 +1378,7 @@ See bt_field_array_borrow_element_field_by_index().
 */
 extern const bt_field *
 bt_field_array_borrow_element_field_by_index_const(
-		const bt_field *field, uint64_t index);
+		const bt_field *field, uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1185,7 +1417,8 @@ typedef enum bt_field_array_dynamic_set_length_status {
 @bt_pre_hot{field}
 */
 extern bt_field_array_dynamic_set_length_status
-bt_field_array_dynamic_set_length(bt_field *field, uint64_t length);
+bt_field_array_dynamic_set_length(bt_field *field, uint64_t length)
+		__BT_NOEXCEPT;
 
 /*! @} */
 
@@ -1225,7 +1458,7 @@ bt_field_array_dynamic_set_length(bt_field *field, uint64_t length);
     \c const version of this function.
 */
 extern bt_field *bt_field_structure_borrow_member_field_by_index(
-		bt_field *field, uint64_t index);
+		bt_field *field, uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1236,7 +1469,7 @@ See bt_field_structure_borrow_member_field_by_index().
 */
 extern const bt_field *
 bt_field_structure_borrow_member_field_by_index_const(
-		const bt_field *field, uint64_t index);
+		const bt_field *field, uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1244,7 +1477,7 @@ bt_field_structure_borrow_member_field_by_index_const(
     \bt_struct_field \bt_p{field}.
 
 If there's no member having the name \bt_p{name} in the
-\ref api-tir-fc-struct "class" of \bt_p{field}, this function
+\ref api-tir-fc-struct "class" of \bt_p{field}, then this function
 returns \c NULL.
 
 @param[in] field
@@ -1269,7 +1502,7 @@ returns \c NULL.
     \c const version of this function.
 */
 extern bt_field *bt_field_structure_borrow_member_field_by_name(
-		bt_field *field, const char *name);
+		bt_field *field, const char *name) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1280,7 +1513,7 @@ See bt_field_structure_borrow_member_field_by_name().
 */
 extern const bt_field *
 bt_field_structure_borrow_member_field_by_name_const(
-		const bt_field *field, const char *name);
+		const bt_field *field, const char *name) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -1302,7 +1535,8 @@ bt_field_structure_borrow_member_field_by_name_const(
 @bt_pre_not_null{field}
 @bt_pre_is_opt_field{field}
 */
-extern void bt_field_option_set_has_field(bt_field *field, bt_bool has_field);
+extern void bt_field_option_set_has_field(bt_field *field, bt_bool has_field)
+		__BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1312,7 +1546,7 @@ extern void bt_field_option_set_has_field(bt_field *field, bt_bool has_field);
     You must call bt_field_option_set_has_field() before you call
     this function.
 
-If \bt_p{field} has no field, this function returns \c NULL.
+If \bt_p{field} has no field, then this function returns \c NULL.
 
 @param[in] field
     Option field from which to borrow the field.
@@ -1333,7 +1567,7 @@ If \bt_p{field} has no field, this function returns \c NULL.
 @sa bt_field_option_borrow_field_const() &mdash;
     \c const version of this function.
 */
-extern bt_field *bt_field_option_borrow_field(bt_field *field);
+extern bt_field *bt_field_option_borrow_field(bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1343,7 +1577,7 @@ extern bt_field *bt_field_option_borrow_field(bt_field *field);
 See bt_field_option_borrow_field().
 */
 extern const bt_field *
-bt_field_option_borrow_field_const(const bt_field *field);
+bt_field_option_borrow_field_const(const bt_field *field) __BT_NOEXCEPT;
 
 /*! @} */
 
@@ -1386,7 +1620,7 @@ typedef enum bt_field_variant_select_option_by_index_status {
 */
 extern bt_field_variant_select_option_by_index_status
 bt_field_variant_select_option_by_index(
-		bt_field *field, uint64_t index);
+		bt_field *field, uint64_t index) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1398,7 +1632,7 @@ bt_field_variant_select_option_by_index(
     you call this function.
 
 @param[in] field
-    Variant field from which to borrow the selected option's field.
+    Variant field from which to borrow the field of its selected option.
 
 @returns
     @parblock
@@ -1412,14 +1646,14 @@ bt_field_variant_select_option_by_index(
 @bt_pre_is_var_field{field}
 
 @sa bt_field_variant_select_option_by_index() &mdash;
-    Sets a variant field's selected option.
+    Sets the selected option of a variant field.
 @sa bt_field_variant_get_selected_option_index() &mdash;
-    Returns the index of a variant field's selected option.
+    Returns the index of the selected option of a variant field.
 @sa bt_field_variant_borrow_selected_option_field_const() &mdash;
     \c const version of this function.
 */
 extern bt_field *bt_field_variant_borrow_selected_option_field(
-		bt_field *field);
+		bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1430,7 +1664,7 @@ See bt_field_variant_borrow_selected_option_field().
 */
 extern const bt_field *
 bt_field_variant_borrow_selected_option_field_const(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1447,10 +1681,10 @@ bt_field_variant_borrow_selected_option_field_const(
 @bt_pre_is_var_field{field}
 
 @sa bt_field_variant_borrow_selected_option_field_const() &mdash;
-    Borrows the field of a variant field's selected option.
+    Borrows the field of the selected option of a variant field.
 */
 extern uint64_t bt_field_variant_get_selected_option_index(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1465,7 +1699,7 @@ bt_field_class_variant_borrow_option_by_index(
 @endcode
 
 @param[in] field
-    Variant field of which to get the selected option's class.
+    Variant field of which to borrow the class of its selected option.
 
 @returns
     Class of the selected option of \bt_p{field}.
@@ -1475,7 +1709,7 @@ bt_field_class_variant_borrow_option_by_index(
 */
 extern const bt_field_class_variant_option *
 bt_field_variant_borrow_selected_option_class_const(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1490,7 +1724,7 @@ bt_field_class_variant_with_selector_field_integer_unsigned_borrow_option_by_ind
 @endcode
 
 @param[in] field
-    Variant field of which to get the selected option's class.
+    Variant field of which to borrow the class of its selected option.
 
 @returns
     Class of the selected option of \bt_p{field}.
@@ -1500,7 +1734,7 @@ bt_field_class_variant_with_selector_field_integer_unsigned_borrow_option_by_ind
 */
 extern const bt_field_class_variant_with_selector_field_integer_unsigned_option *
 bt_field_variant_with_selector_field_integer_unsigned_borrow_selected_option_class_const(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*!
 @brief
@@ -1515,7 +1749,7 @@ bt_field_class_variant_with_selector_field_integer_signed_borrow_option_by_index
 @endcode
 
 @param[in] field
-    Variant field of which to get the selected option's class.
+    Variant field of which to borrow the class of its selected option.
 
 @returns
     Class of the selected option of \bt_p{field}.
@@ -1525,7 +1759,7 @@ bt_field_class_variant_with_selector_field_integer_signed_borrow_option_by_index
 */
 extern const bt_field_class_variant_with_selector_field_integer_signed_option *
 bt_field_variant_with_selector_field_integer_signed_borrow_selected_option_class_const(
-		const bt_field *field);
+		const bt_field *field) __BT_NOEXCEPT;
 
 /*! @} */
 
